.. Fragapy documentation master file, created by
   sphinx-quickstart on Thu Oct 27 04:19:05 2011.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to Fragapy's documentation!
===================================

Fragapy is shared library made and sustained by people from Fragaria, s.r.o. to 
aviod reinventing the wheel for things that have been written before.

The library has no precise aim so you should think about it as heap of things
that proven to be useful and so someone has put them here.

Contents:

.. toctree::
   :maxdepth: 2
   :glob: 
   
   adminhelp
   amazon
   auth
   common
   ella_index
   odt
   soft_delete_models
   static_sitemaps
   unix
   versioning

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

